@@ -1,8 +1,11 @@
 """Contains thermostats structure parser."""
+from __future__ import annotations
 
-from typing import Any, Dict, Final, List, Optional, Tuple
+from collections.abc import MutableSequence
+from typing import Final, Optional, Tuple
 
 from pyplumio import util
+from pyplumio.helpers.typing import Records
 
 THERMOSTATS: Final = "thermostats"
 ECOSTER_CONTACTS: Final = "contacts"
@@ -13,14 +16,9 @@ ECOSTER_TARGET: Final = "target"
 
 
 def from_bytes(
-    message: bytearray, offset: int = 0, data: Optional[Dict[str, Any]] = None
-) -> Tuple[Dict[str, Any], int]:
-    """Parses frame message into usable data.
-
-    Keyword arguments:
-        message -- message bytes
-        offset -- current data offset
-    """
+    message: bytearray, offset: int = 0, data: Optional[Records] = None
+) -> Tuple[Records, int]:
+    """Parse bytes and return message data and offset."""
     if data is None:
         data = {}
 
@@ -28,7 +26,7 @@ def from_bytes(
         offset += 1
         return data, offset
 
-    thermostats: List[Dict[str, Any]] = []
+    thermostats: MutableSequence[Records] = []
     therm_contacts = message[offset]
     offset += 1
     therm_number = message[offset]
@@ -37,7 +35,7 @@ def from_bytes(
         contact_mask = 1
         schedule_mask = 1 << 3
         for _ in range(1, therm_number + 1):
-            therm: Dict[str, Any] = {}
+            therm: Records = {}
             therm[ECOSTER_CONTACTS] = bool(therm_contacts & contact_mask)
             therm[ECOSTER_SCHEDULE] = bool(therm_contacts & schedule_mask)
             therm[ECOSTER_MODE] = message[offset]
